@@ -63,15 +63,6 @@ class PeopleAbridged(IDdEnergyBaseModel):
                 'Sum of radiant and latent fractions cannot be greater than 1.'
         return values
 
-    class Config:
-        @staticmethod
-        def schema_extra(schema, model):
-            schema['properties']['latent_fraction']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/Autocalculate"},
-                    {"type": "number", "minimum": 0, "maximum": 1}
-            ]
-
 
 class People(PeopleAbridged):
 
@@ -93,25 +84,6 @@ class People(PeopleAbridged):
         'individual person in the room.'
     )
 
-    class Config:
-        @staticmethod
-        def schema_extra(schema, model):
-            schema['properties']['latent_fraction']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/Autocalculate"},
-                    {"type": "number", "minimum": 0, "maximum": 1}
-            ]
-            schema['properties']['occupancy_schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-            schema['properties']['activity_schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-
 
 class LightingAbridged(IDdEnergyBaseModel):
 
@@ -180,15 +152,6 @@ class Lighting(LightingAbridged):
         'complete lighting profile.'
     )
 
-    class Config:
-        @staticmethod
-        def schema_extra(schema, model):
-            schema['properties']['schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-
 
 class _EquipmentBase(IDdEnergyBaseModel):
 
@@ -261,15 +224,6 @@ class ElectricEquipment(ElectricEquipmentAbridged):
         'a complete equipment profile.'
     )
 
-    class Config:
-        @staticmethod
-        def schema_extra(schema, model):
-            schema['properties']['schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-
 
 class GasEquipmentAbridged(_EquipmentBase):
 
@@ -288,15 +242,6 @@ class GasEquipment(GasEquipmentAbridged):
         'a complete equipment profile.'
     )
 
-    class Config:
-        @staticmethod
-        def schema_extra(schema, model):
-            schema['properties']['schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-
 
 class InfiltrationAbridged(IDdEnergyBaseModel):
 
@@ -346,15 +291,6 @@ class Infiltration(InfiltrationAbridged):
         'to yield a complete infiltration profile.'
     )
 
-    class Config:
-        @staticmethod
-        def schema_extra(schema, model):
-            schema['properties']['schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-
 
 class VentilationAbridged(IDdEnergyBaseModel):
 
@@ -413,15 +349,6 @@ class Ventilation(VentilationAbridged):
         'ventilation profile.'
     )
 
-    class Config:
-        @staticmethod
-        def schema_extra(schema, model):
-            schema['properties']['schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-
 
 class SetpointAbridged(IDdEnergyBaseModel):
     """Used to specify information about the setpoint schedule."""
@@ -502,27 +429,3 @@ class Setpoint(SetpointAbridged):
         description='Schedule for the dehumidification setpoint. The values '
         'in this schedule should be in [%].'
     )
-
-    class Config:
-        @staticmethod
-        def schema_extra(schema, model):
-            schema['properties']['cooling_schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-            schema['properties']['heating_schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-            schema['properties']['humidifying_schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
-            schema['properties']['dehumidifying_schedule']['anyOf'] = \
-                [
-                    {"$ref": "#/components/schemas/ScheduleRuleset"},
-                    {"$ref": "#/components/schemas/ScheduleFixedInterval"}
-            ]
